@@ -4,11 +4,13 @@ QUEUEDIR="$HOME/.msmtpqueue"
 LOCKFILE="$QUEUEDIR/.lock"
 MAXWAIT=120
 
+OPTIONS=$@
+
 # wait for a lock that another instance has set
-SECONDS=0
-while [ -e "$LOCKFILE" -a "$SECONDS" -lt "$MAXWAIT" ]; do
+WAIT=0
+while [ -e "$LOCKFILE" -a "$WAIT" -lt "$MAXWAIT" ]; do
 	sleep 1
-	SECONDS="`expr "$SECONDS" + 1`"
+	WAIT="`expr "$WAIT" + 1`"
 done
 if [ -e "$LOCKFILE" ]; then
 	echo "Cannot use $QUEUEDIR: waited $MAXWAIT seconds for"
@@ -32,14 +34,14 @@ touch "$LOCKFILE" || exit 1
 
 # process all mails
 for MAILFILE in *.mail; do
-	echo "*** Sending $MAILFILE..."
 	MSMTPFILE="`echo $MAILFILE | sed -e 's/mail/msmtp/'`"
+	echo "*** Sending $MAILFILE to `sed -e 's/^.*-- \(.*$\)/\1/' $MSMTPFILE` ..."
 	if [ ! -f "$MSMTPFILE" ]; then
 		echo "No corresponding file $MSMTPFILE found"
 		echo "FAILURE"
 		continue
 	fi
-	msmtp `cat "$MSMTPFILE"` < "$MAILFILE"
+	msmtp $OPTIONS `cat "$MSMTPFILE"` < "$MAILFILE"
 	if [ $? -eq 0 ]; then
 		rm "$MAILFILE" "$MSMTPFILE"
 		echo "$MAILFILE sent successfully"
